package de.intevation.flys.exports.process;

import org.w3c.dom.Document;

import de.intevation.artifactdatabase.state.ArtifactAndFacet;
import de.intevation.flys.exports.XYChartGenerator;

/**
 * A processor is intended to generate an output e.g. curve in a chart diagramm from
 * arbitrary data input which can be reused in several generators.
 *
 * @author <a href="mailto:bjoern.ricks@intevation.de">Björn Ricks</a>
 */
public interface Processor {

    /**
     * Processes data to generate e.g. a chart.
     *
     * @param generator XYChartGenerator to add output on.
     * @param aandf       The artifact and facet
     * @param theme      The theme that contains styling information.
     * @param visible       The visibility of the curve.
     * @param index        The index of the curve
     */
    public void doOut(
            XYChartGenerator generator,
            ArtifactAndFacet    aandf,
            Document             theme,
            boolean               visible,
            int                         index);

    /**
     * Returns true if the Processor class is able to generate output for a facet type
     *
     * @param facettype Name of the facet type
     * @return true if the facettype can be processed
     */
    public boolean canHandle(String facettype);
}
